# Installation

```bash
pip install frd2vtu
```

### Requirements

- Python >= 3.10
- pyvista >= 0.44.2
- pandas >= 2.2.0
- numpy >= 2.2.6
- rich-click
- treeparse

These dependencies are automatically installed with the package.
